# Scikit-learn example on the iris dataset
This folder contains a simple example script (main.py) used to showcase the simplicity of integrating
 Oríon into an existing workflow. We encourage reading the example on the [documentation](https://orion.readthedocs.io/en/stable/tutorials/scikit-learn.html).

## Pre-requisites
- Install the dependencies `$ pip install -r requirements.txt`
- Configure Oríon database ([documentation](https://orion.readthedocs.io/en/stable/install/database.html))
 
